# tree-sitter-epics-db

[![CI][ci]](https://github.com/minijackson/tree-sitter-epics-db/actions/workflows/ci.yml)
[![matrix][matrix]](https://matrix.to/#/#tree-sitter-chat:matrix.org)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-epics-db)
[![crates][crates]](https://crates.io/crates/tree-sitter-epics-db)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-epics-db/)

A Tree-sitter parser for epics-db files.

## References

- <https://docs.epics-controls.org/en/latest/appdevguide/databaseDefinition.html>

[ci]: https://img.shields.io/github/actions/workflow/status/minijackson/tree-sitter-epics-db/ci.yml?logo=github&label=CI
[matrix]: https://img.shields.io/matrix/tree-sitter-chat%3Amatrix.org?logo=matrix&label=matrix
[npm]: https://img.shields.io/npm/v/tree-sitter-epics-db?logo=npm
[crates]: https://img.shields.io/crates/v/tree-sitter-epics-db?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-epics-db?logo=pypi&logoColor=ffd242
